import { CSSProperties, ReactNode } from 'react';
import type { Margins } from '../types';
import { TrackingResult } from './Tracking';
export interface PlotProps {
    /**
     * Width of the SVG in pixels.
     */
    width: number;
    /**
     * Height of the SVG in pixels.
     */
    height: number;
    /**
     * Color scheme used to pick colors for the series.
     * Defaults to the "schemeSet1" from "d3-scale-chromatic".
     */
    colorScheme?: Iterable<string>;
    /**
     * Margins around the plot.
     */
    margin?: Partial<Margins>;
    /**
     * Style applied to the SVG element.
     */
    svgStyle?: CSSProperties;
    /**
     * Id of the SVG element.
     */
    svgId?: string;
    /**
     * Class name of the SVG element.
     */
    svgClassName?: string;
    /**
     * Style applied to the rectangle around the entire plot.
     */
    plotViewportStyle?: CSSProperties;
    /**
     * Style applied to the rectangle around the series viewport.
     */
    seriesViewportStyle?: CSSProperties;
    /**
     * All plot elements.
     */
    children: ReactNode;
    onClick?: (result: TrackingResult) => void;
    onMouseMove?: (result: TrackingResult) => void;
    onMouseUp?: (result: TrackingResult) => void;
    onMouseDown?: (result: TrackingResult) => void;
    onDoubleClick?: (result: TrackingResult) => void;
    onWheel?: (event: TrackingResult) => void;
    onMouseEnter?: (event: React.MouseEvent<SVGRectElement, MouseEvent>) => void;
    onMouseLeave?: (event: React.MouseEvent<SVGRectElement, MouseEvent>) => void;
}
export declare function Plot(props: PlotProps): JSX.Element;
