import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useRef } from 'react';
import { usePlotEventsState, } from './usePlotEvents';
import { initialPlotOverridesState, usePlotOverridesState, } from './usePlotOverrides';
const plotOverridesContext = createContext(initialPlotOverridesState);
export function usePlotOverrides() {
    return useContext(plotOverridesContext);
}
const plotControlsContext = createContext(null);
export function usePlotControls() {
    const plotControls = useContext(plotControlsContext);
    if (!plotControls) {
        throw new Error('usePlotControls must be called in a child of PlotController');
    }
    return plotControls;
}
const plotEventsUserContext = createContext(null);
export function usePlotEvents(handlers) {
    const userContext = useContext(plotEventsUserContext);
    if (!userContext) {
        throw new Error('usePlotEvents must be called in a child of PlotController');
    }
    const ref = useRef(handlers);
    useEffect(() => {
        ref.current = handlers;
    }, [handlers]);
    useEffect(() => {
        userContext.registerHandlers(ref);
        return () => userContext.unregisterHandlers(ref);
    }, [userContext]);
}
const plotEventsPlotContext = createContext(null);
export function usePlotEventsPlotContext() {
    return useContext(plotEventsPlotContext);
}
export function PlotController(props) {
    const { userActions, plotActions } = usePlotEventsState();
    const { overrides, controls } = usePlotOverridesState();
    return (_jsx(plotOverridesContext.Provider, { value: overrides, children: _jsx(plotControlsContext.Provider, { value: controls, children: _jsx(plotEventsUserContext.Provider, { value: userActions, children: _jsx(plotEventsPlotContext.Provider, { value: plotActions, children: props.children }, void 0) }, void 0) }, void 0) }, void 0));
}
//# sourceMappingURL=plotControllerContext.js.map