import { useMemo, useRef } from 'react';
const initialState = {
    currentPlot: null,
    plots: new Set(),
    handlers: new Set(),
};
export function usePlotEventsState() {
    const plotEvents = useRef(initialState);
    const userActions = useMemo(() => ({
        registerHandlers(handlersRef) {
            plotEvents.current.handlers.add(handlersRef);
        },
        unregisterHandlers(handlersRef) {
            plotEvents.current.handlers.delete(handlersRef);
        },
    }), []);
    const plotActions = useMemo(() => {
        return {
            registerPlot(plotId) {
                plotEvents.current.plots.add(plotId);
            },
            unregisterPlot(plotId) {
                plotEvents.current.plots.delete(plotId);
            },
            handleEvent(plotId, eventType, eventData) {
                if (eventType === 'onMouseDown') {
                    plotEvents.current.currentPlot = plotId;
                }
                if (eventType === 'onMouseUp') {
                    plotEvents.current.currentPlot = null;
                }
                if (plotEvents.current.currentPlot !== null &&
                    plotEvents.current.currentPlot !== plotId) {
                    // Ignore events on other plots.
                    return;
                }
                for (const handler of plotEvents.current.handlers) {
                    if (handler.current[eventType]) {
                        handler.current[eventType](eventData);
                    }
                }
            },
        };
    }, []);
    return { userActions, plotActions };
}
//# sourceMappingURL=usePlotEvents.js.map