import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Line } from '../components/Annotations/Line';
import { Rectangle, } from '../components/Annotations/Rectangle';
import { usePlotControls, usePlotEvents, } from '../contexts/plotController/plotControllerContext';
import { useStartMoveEnd } from './useStartMoveEnd';
export function useAxisZoom(options = {}) {
    const { direction = 'horizontal', axisId = direction === 'horizontal' ? 'x' : 'y', color = 'red', rectangleStyle, lineStyle, } = options;
    const plotControls = usePlotControls();
    const startMoveEnd = useStartMoveEnd({
        onEnd(data) {
            const start = startMoveEnd.start.clampedCoordinates[axisId];
            const end = data.clampedCoordinates[axisId];
            if (start === end) {
                return;
            }
            plotControls.setAxis(axisId, {
                min: Math.min(start, end),
                max: Math.max(start, end),
            });
        },
    });
    usePlotEvents({
        onDoubleClick({ event: { button } }) {
            if (button !== 0)
                return;
            plotControls.resetAxis(axisId);
        },
    });
    if (!(startMoveEnd === null || startMoveEnd === void 0 ? void 0 : startMoveEnd.end)) {
        return { annotations: null };
    }
    const start = startMoveEnd.start.clampedCoordinates[axisId];
    const end = startMoveEnd.end.clampedCoordinates[axisId];
    const lineProps = {
        color,
        strokeWidth: '2',
        style: lineStyle,
    };
    const rectangleProps = {
        color,
        fillOpacity: 0.2,
        style: rectangleStyle,
    };
    let annotations;
    if (direction === 'horizontal') {
        annotations = (_jsxs(_Fragment, { children: [_jsx(Line, { x1: start, x2: start, y1: "0", y2: "100%", ...lineProps }, void 0), _jsx(Rectangle, { x1: start, x2: end, y1: "0", y2: "100%", ...rectangleProps }, void 0), _jsx(Line, { x1: end, x2: end, y1: "0", y2: "100%", ...lineProps }, void 0)] }, void 0));
    }
    else {
        annotations = (_jsxs(_Fragment, { children: [_jsx(Line, { x1: "0", x2: "100%", y1: start, y2: start, ...lineProps }, void 0), _jsx(Rectangle, { x1: "0", x2: "100%", y1: start, y2: end, ...rectangleProps }, void 0), _jsx(Line, { x1: "0", x2: "100%", y1: end, y2: end, ...lineProps }, void 0)] }, void 0));
    }
    return { annotations };
}
//# sourceMappingURL=useAxisZoom.js.map