"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Axis = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const plotContext_1 = require("../../contexts/plotContext");
const axis_1 = require("../../utils/axis");
const LinearAxis_1 = __importDefault(require("./LinearAxis"));
const LogAxis_1 = __importDefault(require("./LogAxis"));
const TimeAxis_1 = __importDefault(require("./TimeAxis"));
function Axis({ id, position, min, max, paddingStart, paddingEnd, flip = false, scale = 'linear', 
// children props
label, displayPrimaryGridLines = false, labelStyle, hidden = false, tickLabelStyle, tickLabelFormat = scale === 'time' ? undefined : (value) => String(value), hiddenLine = false, lineStyle, primaryGridLineStyle, hiddenTicks = false, tickPosition = 'outer', primaryTickLength = 5, primaryTickStyle, secondaryTickLength = 3, secondaryTickStyle, }) {
    const dispatch = (0, plotContext_1.usePlotDispatchContext)();
    const { axisContext, plotWidth, plotHeight } = (0, plotContext_1.usePlotContext)();
    const xY = ['top', 'bottom'].includes(position) ? 'x' : 'y';
    const innerOffset = (0, axis_1.getInnerOffset)(hidden, hiddenTicks, tickPosition, primaryTickLength);
    (0, react_1.useEffect)(() => {
        const minPadding = paddingStart || 0;
        const maxPadding = paddingEnd || 0;
        if (minPadding < 0 || minPadding > 1) {
            throw new Error(`Padding ${position} (${minPadding}) is not between 0 and 1`);
        }
        if (maxPadding < 0 || maxPadding > 1) {
            throw new Error(`Padding ${position} (${maxPadding}) is not between 0 and 1`);
        }
        dispatch({
            type: 'newAxis',
            payload: {
                id: id || xY,
                position,
                min,
                max,
                paddingStart: minPadding,
                paddingEnd: maxPadding,
                flip,
                scale,
                innerOffset,
            },
        });
        return () => dispatch({ type: 'removeAxis', payload: { id: id || xY } });
    }, [
        dispatch,
        flip,
        id,
        innerOffset,
        max,
        min,
        paddingEnd,
        paddingStart,
        position,
        scale,
        xY,
    ]);
    const currentAxis = axisContext[id || xY];
    if (!currentAxis)
        return null;
    const childProps = {
        hidden,
        plotWidth,
        plotHeight,
        displayPrimaryGridLines,
        label,
        labelStyle,
        tickLabelStyle,
        position,
        tickLabelFormat,
        hiddenLine,
        primaryGridLineStyle,
        lineStyle,
        hiddenTicks,
        tickPosition,
        primaryTickLength,
        primaryTickStyle,
        innerOffset,
        secondaryTickLength,
        secondaryTickStyle,
    };
    if (scale === 'linear') {
        return ((0, jsx_runtime_1.jsx)(LinearAxis_1.default, { ...childProps, scale: currentAxis.scale }, void 0));
    }
    if (scale === 'time') {
        return ((0, jsx_runtime_1.jsx)(TimeAxis_1.default, { ...childProps, scale: currentAxis.scale }, void 0));
    }
    else {
        return ((0, jsx_runtime_1.jsx)(LogAxis_1.default, { ...childProps, scale: currentAxis.scale }, void 0));
    }
}
exports.Axis = Axis;
