"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlotEventsState = void 0;
const react_1 = require("react");
const initialState = {
    currentPlot: null,
    plots: new Set(),
    handlers: new Set(),
};
function usePlotEventsState() {
    const plotEvents = (0, react_1.useRef)(initialState);
    const userActions = (0, react_1.useMemo)(() => ({
        registerHandlers(handlersRef) {
            plotEvents.current.handlers.add(handlersRef);
        },
        unregisterHandlers(handlersRef) {
            plotEvents.current.handlers.delete(handlersRef);
        },
    }), []);
    const plotActions = (0, react_1.useMemo)(() => {
        return {
            registerPlot(plotId) {
                plotEvents.current.plots.add(plotId);
            },
            unregisterPlot(plotId) {
                plotEvents.current.plots.delete(plotId);
            },
            handleEvent(plotId, eventType, eventData) {
                if (eventType === 'onMouseDown') {
                    plotEvents.current.currentPlot = plotId;
                }
                if (eventType === 'onMouseUp') {
                    plotEvents.current.currentPlot = null;
                }
                if (plotEvents.current.currentPlot !== null &&
                    plotEvents.current.currentPlot !== plotId) {
                    // Ignore events on other plots.
                    return;
                }
                for (const handler of plotEvents.current.handlers) {
                    if (handler.current[eventType]) {
                        handler.current[eventType](eventData);
                    }
                }
            },
        };
    }, []);
    return { userActions, plotActions };
}
exports.usePlotEventsState = usePlotEventsState;
