"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlotOverridesState = exports.initialPlotOverridesState = void 0;
const react_1 = require("react");
exports.initialPlotOverridesState = {
    axes: {},
};
function usePlotOverridesState() {
    const [overrides, setOverrides] = (0, react_1.useState)(exports.initialPlotOverridesState);
    const controls = (0, react_1.useMemo)(() => {
        return {
            setAxis(axisId, override) {
                setOverrides((state) => ({
                    ...state,
                    axes: { ...state.axes, [axisId]: override },
                }));
            },
            resetAxis(axisId) {
                setOverrides((state) => ({
                    ...state,
                    axes: Object.fromEntries(Object.entries(state.axes).filter(([existingAxisId]) => existingAxisId !== axisId)),
                }));
            },
            setAxes(overrides) {
                setOverrides((state) => {
                    const newAxes = { ...state.axes };
                    Object.entries(overrides).forEach(([axisId, override]) => {
                        newAxes[axisId] = override;
                    });
                    return {
                        ...state,
                        axes: newAxes,
                    };
                });
            },
            resetAxes(axisIds) {
                setOverrides((state) => ({
                    ...state,
                    axes: Object.fromEntries(Object.entries(state.axes).filter(([axisId]) => !axisIds.includes(axisId))),
                }));
            },
        };
    }, []);
    return {
        overrides,
        controls,
    };
}
exports.usePlotOverridesState = usePlotOverridesState;
